

use serde::{Serialize, Deserialize};
use postcard::{from_bytes};
use argh::FromArgs;
use tokio::sync::mpsc;
use std::error::Error;
use std::{env, io};
use tokio::net::UdpSocket;
use tokio::sync::mpsc::channel;
use crate::receiver::Receiver;

mod renderer;
mod receiver;

#[derive(FromArgs)]
///Config options for the client
struct Config {
///listener IP, defaults to 0.0.0.0
#[argh(option, default = "String::from(\"0.0.0.0\")",short='i')]
ip: String,
///listener port
#[argh(option, default = "2137",short='p')]
udpport: usize,
}



#[tokio::main]
async fn main() -> Result<(), Box<dyn Error>>{
    let config:Config = argh::from_env();
    println!("UDP listener Port is {}",config.udpport);
    let socket_addr:std::net::SocketAddr = format!("{}:{}",config.ip,config.udpport).parse::<std::net::SocketAddr>().unwrap_or("0.0.0.0:2137".parse::<std::net::SocketAddr>().unwrap());
    let udp_socket = UdpSocket::bind(socket_addr).await.expect("couldn't bind to address");
    let (sender,rcv) = channel(5);

    let receiver = Receiver{socket:udp_socket,sender};
    receiver.run().await?;
    
    Ok(())
    

}
